=========
Prior Art
=========

There are some great projects operating in the same problem space as tt and might be worth a look. Many of tt's design and feature choices were inspired by the libraries listed on this page. If you think that your library should be listed here, please let me know or submit a PR.


General purpose EDA/Boolean logic
---------------------------------

    * `boolean.py`_
    * `PyEDA`_
    * `LogicNG`_ (Java)
    * `BoolExpr`_ (C++)
    * `EvalEx`_ (Java)


Satisfiability
--------------

    * `PyEDA`_
    * `pycosat`_
    * `SATisPy`_


.. _boolean.py: https://github.com/bastikr/boolean.py
.. _BoolExpr: https://github.com/cjdrake/boolexpr
.. _EvalEx: https://github.com/uklimaschewski/EvalEx
.. _LogicNG: https://github.com/logic-ng/LogicNG
.. _pycosat: https://github.com/ContinuumIO/pycosat
.. _PyEDA: https://github.com/cjdrake/pyeda
.. _SATisPy: https://github.com/netom/satispy/
